@@ -1,13 +1,13 @@
 # -*- coding: utf-8 -*-
 __name__ = "orbis_eval"
-__version__ = "2.2.4"
+__version__ = "2.3.0"
 __author__ = "fabod"
 __year__ = "2019"
 __description__ = "An Extendable Evaluation Pipeline for Named Entity Drill-Down Analysis"
 __license__ = "GPL2"
 __min_python_version__ = "3.6"
 __requirements_file__ = "requirements.txt"
-__url__ = "https://orbis-eval.github.io/Orbis/"
+__url__ = "https://github.com/orbis-eval/orbis_eval"
 __type__ = "main"
 __classifiers__ = [
     "Framework :: orbis-eval",
@@ -19,10 +19,6 @@ __classifiers__ = [
     "Programming Language :: Python :: 3.7"
 ]
 __plugins__ = [
-    "orbis_plugin_aggregation_dbpedia_entity_types",
-    "orbis_plugin_aggregation_monocle",
-    "orbis_plugin_aggregation_gold_gs",
-    "orbis_plugin_aggregation_serial_corpus",
     "orbis_plugin_aggregation_local_cache",
     "orbis_plugin_aggregation_aida",
     "orbis_plugin_aggregation_babelfly",
