@@ -11,6 +11,7 @@ import uuid
 from orbis_eval.core import app
 
 import logging
+
 logger = logging.getLogger(__name__)
 
 
@@ -39,6 +40,7 @@ class Rucksack(object):
         rucksack['config'] = deepcopy(self.config)
         rucksack['data'] = {}
         rucksack['data']['corpus'] = {}
+        rucksack['data']['corpus_modified'] = {}
         rucksack['data']['gold'] = {}
         rucksack['data']['computed'] = {}
         rucksack['results'] = {}
@@ -51,11 +53,25 @@ class Rucksack(object):
         rucksack['metadata']['corpus'] = {'source': None, 'download_time': None}
 
         if self.config:
-            rucksack['config']['data_set_path'] = os.path.join(app.paths.corpora_dir, self.config['aggregation']['input']['data_set']['name'])
-            rucksack['config']['corpus_path'] = os.path.abspath(os.path.join(rucksack['config']['data_set_path'], 'corpus'))
+            rucksack['config']['data_set_path'] = os.path.join(app.paths.corpora_dir,
+                                                               self.config['aggregation']['input']['data_set']['name'])
+            rucksack['config']['corpus_path'] = os.path.abspath(
+                os.path.join(rucksack['config']['data_set_path'], 'corpus'))
             rucksack['config']['gold_path'] = os.path.abspath(os.path.join(rucksack['config']['data_set_path'], 'gold'))
-            rucksack['config']['corpus_source_file'] = os.path.abspath(os.path.join(rucksack['config']['data_set_path'], 'source.txt'))
-            rucksack['config']['computed_path'] = os.path.abspath(os.path.join(rucksack['config']['data_set_path'], 'computed', self.config['aggregation']['service']['name'])) if rucksack['config']['aggregation']['service']['location'] == "local" else None
+            rucksack['config']['corpus_source_file'] = os.path.abspath(
+                os.path.join(rucksack['config']['data_set_path'], 'source.txt'))
+            if 'service' in self.config['aggregation']:
+                rucksack['config']['computed_path'] = os.path.abspath(
+                    os.path.join(rucksack['config']['data_set_path'], 'computed',
+                                 self.config['aggregation']['service']['name'])) if \
+                rucksack['config']['aggregation']['service']['location'] == "local" else None
+            else:
+                rucksack['config']['aggregation']['service'] = {'name': None, 'location': None}
+
+            if 'evaluation' not in self.config:
+                rucksack['config']['evaluation'] = {'name': None}
+                rucksack['config']['scoring'] = {'name': None}
+                rucksack['config']['metrics'] = {'name': None}
 
         return rucksack
 
@@ -78,8 +94,14 @@ class Rucksack(object):
         self.open['metadata']['corpus']['download_time'] = time
 
     def pack_corpus(self, corpus):
+        # print(f"81: corpus: {corpus}")
+
+        for doc, content in corpus.items():
+            if doc.split("-")[-1] == "modified":
+                self.open['data']['corpus_modified'][doc.replace("-modified", "")] = content
+            else:
+                self.open['data']['corpus'][doc] = content
 
-        self.open['data']['corpus'] = corpus
         self.pack_source_and_downloadtime()
 
     def pack_computed(self, computed):
@@ -131,10 +153,12 @@ class Rucksack(object):
 
     def itemview(self, key):
         data = self.open['data']
+
         if data['corpus'].get(key, None):
             result = {
                 'index': key,
                 'corpus': data['corpus'].get(key, None),
+                'corpus_modified': data['corpus_modified'].get(key, None),
                 'gold': data['gold'].get(key, None),
                 'computed': data['computed'].get(key, None)
             }
@@ -145,9 +169,12 @@ class Rucksack(object):
     def itemsview(self):
         data = self.open['data']
         for key, item in sorted(data['corpus'].items()):
+
             result = {
                 'index': key,
+                'url': data['gold'][key][0]['key'] if len(data['gold'][key]) else "",
                 'corpus': item,
+                'corpus_modified': data['corpus_modified'].get(key, None),
                 'gold': data['gold'].get(key, None),
                 'computed': data['computed'].get(key, None)
             }
@@ -155,19 +182,22 @@ class Rucksack(object):
 
     def result_summary(self, specific=None):
 
-        summary = self.open['results']["summary"]
-        results = summary.get(specific) if specific else summary
-        return results
+        if "summary" in self.open['results']:
+            summary = self.open['results']["summary"]
+            results = summary.get(specific) if specific else summary
+            return results
+        return "No results calculated"
 
     def resultview(self, key, specific=None):
-        items = self.open['results']['items']
-        if items.get(key):
-            response = items[key]
-            if specific:
-                response = response.get(specific)
-            return response
-        else:
-            return None
+        if 'items' in self.open['results']:
+            items = self.open['results']['items']
+            if items.get(key):
+                response = items[key]
+                if specific:
+                    response = response.get(specific)
+                return response
+
+        return {'confusion_matrix': {'fp_ids': [], 'tp_ids': [], 'fn_ids': []}}
 
     def resultsview(self, specific=None):
         items = self.open['results']['items']
